/* Copyright (c) 1989 Carrick Sean Casey. All rights reserved. */

/* save and restore terminal state */

#include <stdio.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sgtty.h>
#include "../forumnet.h"
#include "externs.h"

setterm()
{
	struct sgttyb tty;
	char *tn, *ttyname();
	struct stat sbuf;

	/* get tty settings */
	if (ioctl(0, TIOCGETP, &tty) < 0) {
		perror("TIOCGETP (tty) failed");
		exit(-1);
	}

	/* turn on cbreak - turn off echo */
	tty.sg_flags |= CBREAK;
	tty.sg_flags &= ~ECHO;

	/* set the new flags */
	if (ioctl(0, TIOCSETP, &tty) < 0) {
		perror("TIOCSETP (tty) failed");
		exit(-1);
	}

	/* fiddle with terminal write-permission */
	if (m_nomesg) {
		/* get tty name */
		if ((tn = ttyname(0)) != NULL) {
			/* find it's mode */
			if (stat(tn, &sbuf) != -1) {
				if (sbuf.st_mode & 02)
					/* if writable, change it */
					chmod(tn, 0600);
				else
					/* otherwise, forget all about it */
					m_nomesg = 0;
			}
		}
	}

}

restoreterm()
{
	struct sgttyb tty;
	char *tn, *ttyname();

	/* get the terminal's flags */
	if (ioctl(0, TIOCGETP, &tty) < 0) {
		perror("TIOCGETP (tty) failed");
		exit(-1);
	}

	/* turn off cbreak - turn on echo */
	tty.sg_flags &= ~CBREAK;
	tty.sg_flags |= ECHO;

	/* set the flags */
	if (ioctl(0, TIOCSETP, &tty) < 0) {
		perror("TIOCSETP (tty) failed");
		exit(-1);
	}

	/* re-write-enable the term if needed */
	if (m_nomesg) {
		/* get tty name */
		if ((tn = ttyname(0)) != NULL) {
			/* write-enable it */
			chmod(tn, 0622);
		}
	}
}
